@@ -21,8 +21,8 @@ import os
 import sys
 
 import click
+from click_shell import shell
 
-from incenp.nucleus.lamin import shell
 from incenp.pebble import __version__
 from incenp.pebble.cache import Vault
 from incenp.pebble.editor import edit_credential
@@ -181,6 +181,7 @@ class PebbleContext(object):
         else:
             host = self._config.get(section, 'host')
             user = self._config.get(section, 'user')
+            password = None
             if self._config.has_option(section, 'password'):
                 password = self._config.get(section, 'password')
             elif use_keyring:
